==> ejc-businessplan-impl-3.0.0-20220329.134247-55-sources.jar: com/ejianc/business/change/vo/ChangeFundsplanningVO.java <==
package com.ejianc.business.change.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 项目资金管理策划变更表
 * 
 * @author generator
 * 
 */
public class ChangeFundsplanningVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String changeReason; // 变更原因
    private java.util.Date effectTime; // 生效时间
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private Integer changeId; // 变更ID
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long fundsplanningId; // 项目资金管理策划变更ID
    private String billCode; // 单据编码
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private Long agentId; // 经办人id
    private String agentName; // 经办人名称
    private String remarks; // 备注

    private List<ChangeFundsplanningdetailVO> FundsplanningdetailVos = new ArrayList<>(); // 项目资金管理策划变更子表


    /**
     * 生效时间
     */
    public java.util.Date getEffectTime() {
        return effectTime;
    }

    /**
     * 生效时间
     */
    public void setEffectTime(java.util.Date effectTime) {
        this.effectTime = effectTime;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }

    /**
     * 变更ID
     */
    public Integer getChangeId() {
        return changeId;
    }

    /**
     * 变更ID
     */
    public void setChangeId(Integer changeId) {
        this.changeId = changeId;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    /**
     * 项目资金管理策划变更ID
     */
    public Long getFundsplanningId() {
        return fundsplanningId;
    }

    /**
     * 项目资金管理策划变更ID
     */
    public void setFundsplanningId(Long fundsplanningId) {
        this.fundsplanningId = fundsplanningId;
    }

    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode = "ejc-zjkj-project")
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    /**
     * 所属组织id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    /**
     * 所属组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    /**
     * 项目部id
     */
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    /**
     * 经办人id
     */
    public Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }

    /**
     * 经办人名称
     */
    public String getAgentName() {
        return agentName;
    }

    /**
     * 经办人名称
     */
    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }

    /**
     * 备注
     */
    public String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    /**
     * 变更原因
     */
    public String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }

    public List<ChangeFundsplanningdetailVO> getFundsplanningdetailVos() {
        return FundsplanningdetailVos;
    }

    public void setFundsplanningdetailVos(List<ChangeFundsplanningdetailVO> fundsplanningdetailVos) {
        FundsplanningdetailVos = fundsplanningdetailVos;
    }
}

==> ejc-businessplan-impl-3.0.0-20241021.063348-193-sources.jar: com/ejianc/business/change/vo/ChangeFundsplanningVO.java <==
package com.ejianc.business.change.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 项目资金管理策划变更表
 * 
 * @author generator
 * 
 */
public class ChangeFundsplanningVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String changeReason; // 变更原因
    private java.util.Date effectTime; // 生效时间
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private Integer changeId; // 变更ID
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long fundsplanningId; // 项目资金管理策划变更ID
    private String billCode; // 单据编码
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private Long agentId; // 经办人id
    private String agentName; // 经办人名称
    private String remarks; // 备注

    private List<ChangeFundsplanningdetailVO> fundsplanningdetailEntities = new ArrayList<>(); // 项目资金管理策划变更子表


    /**
     * 生效时间
     */
    public java.util.Date getEffectTime() {
        return effectTime;
    }

    /**
     * 生效时间
     */
    public void setEffectTime(java.util.Date effectTime) {
        this.effectTime = effectTime;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }

    /**
     * 变更ID
     */
    public Integer getChangeId() {
        return changeId;
    }

    /**
     * 变更ID
     */
    public void setChangeId(Integer changeId) {
        this.changeId = changeId;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    /**
     * 项目资金管理策划变更ID
     */
    public Long getFundsplanningId() {
        return fundsplanningId;
    }

    /**
     * 项目资金管理策划变更ID
     */
    public void setFundsplanningId(Long fundsplanningId) {
        this.fundsplanningId = fundsplanningId;
    }

    /**
     * 单据编码
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编码
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode = "ejc-zjkj-project")
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    /**
     * 所属组织id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    /**
     * 所属组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    /**
     * 项目部id
     */
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    /**
     * 经办人id
     */
    @ReferSerialTransfer(referCode="idm-user")
    public Long getAgentId() {
        return agentId;
    }

    /**
     * 经办人id
     */
    @ReferDeserialTransfer
    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }

    /**
     * 经办人名称
     */
    public String getAgentName() {
        return agentName;
    }

    /**
     * 经办人名称
     */
    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }

    /**
     * 备注
     */
    public String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    /**
     * 变更原因
     */
    public String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(String changeReason) {
        this.changeReason = changeReason;
    }

    public List<ChangeFundsplanningdetailVO> getFundsplanningdetailEntities() {
        return fundsplanningdetailEntities;
    }

    public void setFundsplanningdetailEntities(List<ChangeFundsplanningdetailVO> fundsplanningdetailEntities) {
        this.fundsplanningdetailEntities = fundsplanningdetailEntities;
    }
}
